==> relateddigital_flutter-0.2.5.tar.gz: lib/constants.dart <==
class Constants {
  static const String CHANNEL_NAME = 'relateddigital_flutter';

  static const String M_INIT = 'RD/init';
  static const String M_PERMISSION = 'RD/requestPermission';
  static const String M_TOKEN_RETRIEVED = 'RD/getToken';
  static const String M_NOTIFICATION_OPENED = 'RD/openNotification';
  static const String M_EURO_USER_ID = 'RD/setEuroUserId';
  static const String M_EMAIL_WITH_PERMISSION = 'RD/setEmail';
  static const String M_USER_PROPERTY = 'RD/setUserProperty';
  static const String M_APP_VERSION = 'RD/setAppVersion';
  static const String M_NOTIFICATION_PERMISSION = 'RD/setPushNotificationPermission';
  static const String M_EMAIL_PERMISSION = 'RD/setEmailPermission';
  static const String M_PHONE_PERMISSION = 'RD/setPhoneNumberPermission';
  static const String M_BADGE = 'RD/setBadgeCount';
  static const String M_ADVERTISING = 'RD/setAdvertisingIdentifier';
  static const String M_TWITTER = 'RD/setTwitterId';
  static const String M_FACEBOOK = 'RD/setFacebookId';
  static const String M_CUSTOM_EVENT = 'VL/customEvent';
  static const String M_REGISTER_EMAIL = 'RD/registerEmail';
  static const String M_RECOMMENDATIONS = 'VL/getRecommendations';
  static const String M_STORY_ITEM_CLICK = 'VL/onStoryItemClick';
  static const String M_STORY_CLEAR_CACHE = 'VL/clearStoryCache';
  static const String M_FAV_ATTRIBUTE = 'VL/getFavAttributes';
  static const String M_LOGOUT = 'VL/logout';
  static const String M_LOGIN = 'VL/login';
  static const String M_SIGNUP = 'VL/signUp';
  static const String M_GET_EXVISITORID = 'VL/getExVisitorID';
  static const String M_APP_TRACKER = 'VL/appTracker';

  static const String VL_TOKEN_KEY = 'RegisterToken';
  static const String VL_TOKEN_PARAM = 'OM.sys.TokenID';
  static const String VL_APP_ID_PARAM = 'OM.sys.AppID';
  static const String STORY_VIEW_NAME = 'StoryView';
  static const String VL_UTM_CAMPAIGN_PARAM = 'utm_campaign';
  static const String VL_UTM_SOURCE_PARAM = 'utm_source';
  static const String VL_UTM_MEDIUM_PARAM = 'utm_medium';
  static const String VL_UTM_EVENT_KEY = 'OM_evt.gif';
  static const String VL_UTM_EVENT_PARAMS_KEY = 'params';
}

==> relateddigital_flutter-0.4.1.tar.gz: lib/constants.dart <==
class Constants {
  static const String CHANNEL_NAME = 'relateddigital_flutter';

  static const String M_INIT = 'RD/init';
  static const String M_PERMISSION = 'RD/requestPermission';
  static const String M_TOKEN_RETRIEVED = 'RD/getToken';
  static const String M_NOTIFICATION_OPENED = 'RD/openNotification';
  static const String M_EURO_USER_ID = 'RD/setEuroUserId';
  static const String M_EMAIL_WITH_PERMISSION = 'RD/setEmail';
  static const String M_USER_PROPERTY = 'RD/setUserProperty';
  static const String M_APP_VERSION = 'RD/setAppVersion';
  static const String M_NOTIFICATION_PERMISSION =
      'RD/setPushNotificationPermission';
  static const String M_EMAIL_PERMISSION = 'RD/setEmailPermission';
  static const String M_PHONE_PERMISSION = 'RD/setPhoneNumberPermission';
  static const String M_BADGE = 'RD/setBadgeCount';
  static const String M_ADVERTISING = 'RD/setAdvertisingIdentifier';
  static const String M_TWITTER = 'RD/setTwitterId';
  static const String M_FACEBOOK = 'RD/setFacebookId';
  static const String M_CUSTOM_EVENT = 'VL/customEvent';
  static const String M_REGISTER_EMAIL = 'RD/registerEmail';
  static const String M_RECOMMENDATIONS = 'VL/getRecommendations';
  static const String M_STORY_ITEM_CLICK = 'VL/onStoryItemClick';
  static const String M_STORY_CLEAR_CACHE = 'VL/clearStoryCache';
  static const String M_FAV_ATTRIBUTE = 'VL/getFavAttributes';
  static const String M_LOGOUT = 'VL/logout';
  static const String M_LOGIN = 'VL/login';
  static const String M_SIGNUP = 'VL/signUp';
  static const String M_GET_EXVISITORID = 'VL/getExVisitorID';
  static const String M_APP_TRACKER = 'VL/appTracker';
  static const String M_GET_PUSH_MESSAGES = 'RD/getPushMessages';
  static const String M_REQUEST_IDFA = 'VL/requestIDFA';
  static const String M_SEND_LOCATION_PERMISSION = 'VL/sendLocationPermission';

  static const String VL_TOKEN_KEY = 'RegisterToken';
  static const String VL_TOKEN_PARAM = 'OM.sys.TokenID';
  static const String VL_APP_ID_PARAM = 'OM.sys.AppID';
  static const String STORY_VIEW_NAME = 'StoryView';
  static const String VL_UTM_CAMPAIGN_PARAM = 'utm_campaign';
  static const String VL_UTM_SOURCE_PARAM = 'utm_source';
  static const String VL_UTM_MEDIUM_PARAM = 'utm_medium';
  static const String VL_UTM_EVENT_KEY = 'OM_evt.gif';
  static const String VL_UTM_EVENT_PARAMS_KEY = 'params';
}
